pub fn notify_vcpu_timer_expired(vm_id: VMId, vcpu_id: VCpuId)Expand description
Notify that a virtual CPU’s timer has expired.
This function is called when a vCPU’s virtual timer expires and needs to be handled.
Arguments
vm_id- The identifier of the virtual machine.vcpu_id- The identifier of the virtual CPU whose timer expired.
Note
This API may be revised in future versions as the timer virtualization design evolves.